Linux IIO development
 help / color / mirror / Atom feed
* [PATCH] counter: intel-qep: Replace manual mutex logic with lock guards
@ 2026-04-22 21:05 Joao Paulo Menezes Linaris
  2026-04-23 11:42 ` Ilpo Järvinen
  0 siblings, 1 reply; 5+ messages in thread
From: Joao Paulo Menezes Linaris @ 2026-04-22 21:05 UTC (permalink / raw)
  To: ilpo.jarvinen, wbg; +Cc: Joao Paulo Menezes Linaris, Guilherme Dias, linux-iio

Use scoped_guard() for handling mutex lock instead of locking and unlocking mutex explicitly. This improves readability by eliminating the need for gotos and by clearly indicating mutex will be locked only when execution is in scoped_guard() scope.

Signed-off-by: Joao Paulo Menezes Linaris <jplinaris@usp.br>
Co-developed-by: Guilherme Dias <guilhermeabreu200105@usp.br>
Signed-off-by: Guilherme Dias <guilhermeabreu200105@usp.br>
---
 drivers/counter/intel-qep.c | 126 +++++++++++++++++-------------------
 1 file changed, 58 insertions(+), 68 deletions(-)

-- 
2.34.1


^ permalink raw reply related	[flat|nested] 5+ messages in thread
* [PATCH] counter: intel-qep: Replace manual mutex logic with lock guards
@ 2026-05-08  3:40 Joao Paulo Menezes Linaris
  2026-05-08  5:18 ` Maxwell Doose
  0 siblings, 1 reply; 5+ messages in thread
From: Joao Paulo Menezes Linaris @ 2026-05-08  3:40 UTC (permalink / raw)
  To: ilpo.jarvinen, wbg; +Cc: jplinaris, Guilherme Dias, linux-iio

Use scoped_guard() for handling mutex lock instead of locking and
unlocking mutex explicitly. This improves readability by eliminating
the need for gotos and by clearly indicating mutex will be locked only
when execution is in guard scope.

Signed-off-by: Joao Paulo Menezes Linaris <jplinaris@usp.br>
Co-developed-by: Guilherme Dias <guilhermeabreu200105@usp.br>
Signed-off-by: Guilherme Dias <guilhermeabreu200105@usp.br>
---
v1 -> v2:
 - fold the commit message properly
 - replace scoped_guard() with guard()
 - remove unnecessary comments

 drivers/counter/intel-qep.c | 47 +++++++++++--------------------------
 1 file changed, 14 insertions(+), 33 deletions(-)

diff --git a/drivers/counter/intel-qep.c b/drivers/counter/intel-qep.c
index c49c17805..ef6eb3249 100644
--- a/drivers/counter/intel-qep.c
+++ b/drivers/counter/intel-qep.c
@@ -188,25 +188,20 @@ static int intel_qep_ceiling_write(struct counter_device *counter,
 				   struct counter_count *count, u64 max)
 {
 	struct intel_qep *qep = counter_priv(counter);
-	int ret = 0;
 
 	/* Intel QEP ceiling configuration only supports 32-bit values */
 	if (max != (u32)max)
 		return -ERANGE;
 
-	mutex_lock(&qep->lock);
-	if (qep->enabled) {
-		ret = -EBUSY;
-		goto out;
-	}
+	guard(mutex)(&qep->lock);
+	if (qep->enabled)
+		return -EBUSY;
 
 	pm_runtime_get_sync(qep->dev);
 	intel_qep_writel(qep, INTEL_QEPMAX, max);
 	pm_runtime_put(qep->dev);
 
-out:
-	mutex_unlock(&qep->lock);
-	return ret;
+	return 0;
 }
 
 static int intel_qep_enable_read(struct counter_device *counter,
@@ -226,10 +221,10 @@ static int intel_qep_enable_write(struct counter_device *counter,
 	u32 reg;
 	bool changed;
 
-	mutex_lock(&qep->lock);
+	guard(mutex)(&qep->lock);
 	changed = val ^ qep->enabled;
 	if (!changed)
-		goto out;
+		return 0;
 
 	pm_runtime_get_sync(qep->dev);
 	reg = intel_qep_readl(qep, INTEL_QEPCON);
@@ -246,8 +241,6 @@ static int intel_qep_enable_write(struct counter_device *counter,
 	pm_runtime_put(qep->dev);
 	qep->enabled = val;
 
-out:
-	mutex_unlock(&qep->lock);
 	return 0;
 }
 
@@ -279,7 +272,6 @@ static int intel_qep_spike_filter_ns_write(struct counter_device *counter,
 	struct intel_qep *qep = counter_priv(counter);
 	u32 reg;
 	bool enable;
-	int ret = 0;
 
 	/*
 	 * Spike filter length is (MAX_COUNT + 2) clock periods.
@@ -300,11 +292,9 @@ static int intel_qep_spike_filter_ns_write(struct counter_device *counter,
 	if (length > INTEL_QEPFLT_MAX_COUNT(length))
 		return -ERANGE;
 
-	mutex_lock(&qep->lock);
-	if (qep->enabled) {
-		ret = -EBUSY;
-		goto out;
-	}
+	guard(mutex)(&qep->lock);
+	if (qep->enabled)
+		return -EBUSY;
 
 	pm_runtime_get_sync(qep->dev);
 	reg = intel_qep_readl(qep, INTEL_QEPCON);
@@ -316,9 +306,7 @@ static int intel_qep_spike_filter_ns_write(struct counter_device *counter,
 	intel_qep_writel(qep, INTEL_QEPCON, reg);
 	pm_runtime_put(qep->dev);
 
-out:
-	mutex_unlock(&qep->lock);
-	return ret;
+	return 0;
 }
 
 static int intel_qep_preset_enable_read(struct counter_device *counter,
@@ -342,13 +330,9 @@ static int intel_qep_preset_enable_write(struct counter_device *counter,
 {
 	struct intel_qep *qep = counter_priv(counter);
 	u32 reg;
-	int ret = 0;
-
-	mutex_lock(&qep->lock);
-	if (qep->enabled) {
-		ret = -EBUSY;
-		goto out;
-	}
+	guard(mutex)(&qep->lock);
+	if (qep->enabled)
+		return -EBUSY;
 
 	pm_runtime_get_sync(qep->dev);
 	reg = intel_qep_readl(qep, INTEL_QEPCON);
@@ -360,10 +344,7 @@ static int intel_qep_preset_enable_write(struct counter_device *counter,
 	intel_qep_writel(qep, INTEL_QEPCON, reg);
 	pm_runtime_put(qep->dev);
 
-out:
-	mutex_unlock(&qep->lock);
-
-	return ret;
+	return 0;
 }
 
 static struct counter_comp intel_qep_count_ext[] = {
diff --git a/drivers/counter/intel-qep.c b/drivers/counter/intel-qep.c
index c49c17805..199a8d562 100644
--- a/drivers/counter/intel-qep.c
+++ b/drivers/counter/intel-qep.c
@@ -188,25 +188,22 @@ static int intel_qep_ceiling_write(struct counter_device *counter,
 				   struct counter_count *count, u64 max)
 {
 	struct intel_qep *qep = counter_priv(counter);
-	int ret = 0;
 
 	/* Intel QEP ceiling configuration only supports 32-bit values */
 	if (max != (u32)max)
 		return -ERANGE;
 
-	mutex_lock(&qep->lock);
-	if (qep->enabled) {
-		ret = -EBUSY;
-		goto out;
-	}
+	/* Lock mutex while execution in scoped_guard() scope */
+	scoped_guard(mutex, &qep->lock){
+		if (qep->enabled) 
+			return -EBUSY;
 
-	pm_runtime_get_sync(qep->dev);
-	intel_qep_writel(qep, INTEL_QEPMAX, max);
-	pm_runtime_put(qep->dev);
+		pm_runtime_get_sync(qep->dev);
+		intel_qep_writel(qep, INTEL_QEPMAX, max);
+		pm_runtime_put(qep->dev);
+	}
 
-out:
-	mutex_unlock(&qep->lock);
-	return ret;
+	return 0;
 }
 
 static int intel_qep_enable_read(struct counter_device *counter,
@@ -226,28 +223,28 @@ static int intel_qep_enable_write(struct counter_device *counter,
 	u32 reg;
 	bool changed;
 
-	mutex_lock(&qep->lock);
-	changed = val ^ qep->enabled;
-	if (!changed)
-		goto out;
-
-	pm_runtime_get_sync(qep->dev);
-	reg = intel_qep_readl(qep, INTEL_QEPCON);
-	if (val) {
-		/* Enable peripheral and keep runtime PM always on */
-		reg |= INTEL_QEPCON_EN;
-		pm_runtime_get_noresume(qep->dev);
-	} else {
-		/* Let runtime PM be idle and disable peripheral */
-		pm_runtime_put_noidle(qep->dev);
-		reg &= ~INTEL_QEPCON_EN;
+	/* Lock mutex while execution in scoped_guard() scope */
+	scoped_guard(mutex, &qep->lock){
+		changed = val ^ qep->enabled;
+		if (!changed) 
+			return 0;
+
+		pm_runtime_get_sync(qep->dev);
+		reg = intel_qep_readl(qep, INTEL_QEPCON);
+		if (val) {
+			/* Enable peripheral and keep runtime PM always on */
+			reg |= INTEL_QEPCON_EN;
+			pm_runtime_get_noresume(qep->dev);
+		} else {
+			/* Let runtime PM be idle and disable peripheral */
+			pm_runtime_put_noidle(qep->dev);
+			reg &= ~INTEL_QEPCON_EN;
+		}
+		intel_qep_writel(qep, INTEL_QEPCON, reg);
+		pm_runtime_put(qep->dev);
+		qep->enabled = val;
 	}
-	intel_qep_writel(qep, INTEL_QEPCON, reg);
-	pm_runtime_put(qep->dev);
-	qep->enabled = val;
 
-out:
-	mutex_unlock(&qep->lock);
 	return 0;
 }
 
@@ -279,7 +276,6 @@ static int intel_qep_spike_filter_ns_write(struct counter_device *counter,
 	struct intel_qep *qep = counter_priv(counter);
 	u32 reg;
 	bool enable;
-	int ret = 0;
 
 	/*
 	 * Spike filter length is (MAX_COUNT + 2) clock periods.
@@ -300,25 +296,23 @@ static int intel_qep_spike_filter_ns_write(struct counter_device *counter,
 	if (length > INTEL_QEPFLT_MAX_COUNT(length))
 		return -ERANGE;
 
-	mutex_lock(&qep->lock);
-	if (qep->enabled) {
-		ret = -EBUSY;
-		goto out;
+	/* Lock mutex while execution in scoped_guard() scope */
+	scoped_guard(mutex, &qep->lock){
+		if (qep->enabled)
+			return -EBUSY;
+
+		pm_runtime_get_sync(qep->dev);
+		reg = intel_qep_readl(qep, INTEL_QEPCON);
+		if (enable)
+			reg |= INTEL_QEPCON_FLT_EN;
+		else
+			reg &= ~INTEL_QEPCON_FLT_EN;
+		intel_qep_writel(qep, INTEL_QEPFLT, length);
+		intel_qep_writel(qep, INTEL_QEPCON, reg);
+		pm_runtime_put(qep->dev);
 	}
 
-	pm_runtime_get_sync(qep->dev);
-	reg = intel_qep_readl(qep, INTEL_QEPCON);
-	if (enable)
-		reg |= INTEL_QEPCON_FLT_EN;
-	else
-		reg &= ~INTEL_QEPCON_FLT_EN;
-	intel_qep_writel(qep, INTEL_QEPFLT, length);
-	intel_qep_writel(qep, INTEL_QEPCON, reg);
-	pm_runtime_put(qep->dev);
-
-out:
-	mutex_unlock(&qep->lock);
-	return ret;
+	return 0;
 }
 
 static int intel_qep_preset_enable_read(struct counter_device *counter,
@@ -342,28 +336,24 @@ static int intel_qep_preset_enable_write(struct counter_device *counter,
 {
 	struct intel_qep *qep = counter_priv(counter);
 	u32 reg;
-	int ret = 0;
-
-	mutex_lock(&qep->lock);
-	if (qep->enabled) {
-		ret = -EBUSY;
-		goto out;
-	}
 
-	pm_runtime_get_sync(qep->dev);
-	reg = intel_qep_readl(qep, INTEL_QEPCON);
-	if (val)
-		reg &= ~INTEL_QEPCON_COUNT_RST_MODE;
-	else
-		reg |= INTEL_QEPCON_COUNT_RST_MODE;
+	/* Lock mutex while execution in scoped_guard() scope */
+	scoped_guard(mutex, &qep->lock){
+		if (qep->enabled) 
+			return -EBUSY;
 
-	intel_qep_writel(qep, INTEL_QEPCON, reg);
-	pm_runtime_put(qep->dev);
+		pm_runtime_get_sync(qep->dev);
+		reg = intel_qep_readl(qep, INTEL_QEPCON);
+		if (val)
+			reg &= ~INTEL_QEPCON_COUNT_RST_MODE;
+		else
+			reg |= INTEL_QEPCON_COUNT_RST_MODE;
 
-out:
-	mutex_unlock(&qep->lock);
+		intel_qep_writel(qep, INTEL_QEPCON, reg);
+		pm_runtime_put(qep->dev);
+	}
 
-	return ret;
+	return 0;
 }
 
 static struct counter_comp intel_qep_count_ext[] = {
-- 
2.34.1


^ permalink raw reply related	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2026-05-08  5:18 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2026-04-22 21:05 [PATCH] counter: intel-qep: Replace manual mutex logic with lock guards Joao Paulo Menezes Linaris
2026-04-23 11:42 ` Ilpo Järvinen
2026-04-30 22:03   ` Joao Paulo Menezes Linaris
  -- strict thread matches above, loose matches on Subject: below --
2026-05-08  3:40 Joao Paulo Menezes Linaris
2026-05-08  5:18 ` Maxwell Doose

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox